# pytest-mocktcp

pytest mocking of TCP servers

## Dev Setup

First initialise and activate virtual environment:

```
$ ./scripts/init_venv
source venv/bin/activate
```

Next, make the project:

```
$ make
```
